@@ -25,7 +25,7 @@ class Client(object):
     endpoint : str, optional
         Treasure Data API server. If not given, ``https://api.treasuredata.com`` is
         used by default. List of available endpoints is:
-        https://support.treasuredata.com/hc/en-us/articles/360001474288-Sites-and-Endpoints
+        https://tddocs.atlassian.net/wiki/spaces/PD/pages/1085143/Sites+and+Endpoints
 
     database : str, default: 'sample_datasets'
         Name of connected database.
@@ -201,6 +201,15 @@ class Client(object):
             - ``retry_limit`` (int): max number of automatic retries
             - ``wait_interval`` (int): sleep interval until job finish
             - ``wait_callback`` (function): called every interval against job itself
+            - ``engine_version`` (str): run query with Hive 2 if this parameter
+              is set to ``"experimental"`` and ``engine`` denotes Hive.
+              https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
+
+            Meanwhile, when a following argument is set to ``True``, query is
+            deterministically issued via ``tdclient``.
+
+            - ``force_tdclient`` (bool): force Presto engines to issue a query
+              via ``tdclient`` rather than its default ``prestodb`` interface.
 
         Returns
         -------
