@@ -23,7 +23,7 @@ def connect(apikey=None, endpoint=None, **kwargs):
     endpoint : str, optional
         Treasure Data API server. If not given, ``https://api.treasuredata.com`` is
         used by default. List of available endpoints is:
-        https://support.treasuredata.com/hc/en-us/articles/360001474288-Sites-and-Endpoints
+        https://tddocs.atlassian.net/wiki/spaces/PD/pages/1085143/Sites+and+Endpoints
 
     kwargs : dict, optional
         Optional arguments
@@ -126,6 +126,11 @@ def read_td_query(
     Optionally provide an index_col parameter to use one of the columns as
     the index, otherwise default integer index will be used.
 
+    While Presto in pytd has two options to issue a query, by either
+    ``tdclient`` or ``prestodb``, pytd.pandas_td#read_td_query always uses the
+    former to be compatible with the original pandas-td. Use
+    :class:`pytd.Client` to take advantage of the latter option.
+
     Parameters
     ----------
     query : str
@@ -167,6 +172,9 @@ def read_td_query(
         - ``retry_limit`` (int): max number of automatic retries
         - ``wait_interval`` (int): sleep interval until job finish
         - ``wait_callback`` (function): called every interval against job itself
+        - ``engine_version`` (str): run query with Hive 2 if this parameter is
+          set to ``"experimental"`` in ``HiveQueryEngine``.
+          https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
 
     Returns
     -------
@@ -175,6 +183,7 @@ def read_td_query(
     """
     if params is None:
         params = {}
+    params["force_tdclient"] = True
 
     if isinstance(engine, PrestoQueryEngine) and distributed_join is not None:
         header = engine.create_header(
@@ -361,6 +370,7 @@ def to_td(
     chunksize=10000,
     date_format=None,
     writer="bulk_import",
+    **kwargs
 ):
     """Write a DataFrame to a Treasure Data table.
 
@@ -423,6 +433,20 @@ def to_td(
                 :class:`pytd.writer.Writer`, default: 'bulk_import'
         A Writer to choose writing method to Treasure Data. If not given or
         string value, a temporal Writer instance will be created.
+
+    fmt : str, {'csv', 'msgpack'}, default: 'csv'
+        Format for bulk_import.
+
+        - csv
+            Convert dataframe to temporary CSV file. Stable option but slower
+            than msgpack option because pytd saves dataframe as temporary CSV file,
+            then td-client converts it to msgpack.
+            Types of columns are guessed by ``pandas.read_csv`` and it causes
+            unintended type conversion e.g., 0-padded string ``"00012"`` into
+            integer ``12``.
+        - msgpack
+            Convert to temporary msgpack.gz file. Fast option but there is a
+            slight difference on type conversion compared to csv.
     """
     if if_exists == "fail" or if_exists == "error":
         mode = "error"
@@ -442,7 +466,7 @@ def to_td(
     frame = _convert_date_format(frame, date_format)
 
     database, table = name.split(".")
-    con.get_table(database, table).import_dataframe(frame, writer, mode)
+    con.get_table(database, table).import_dataframe(frame, writer, mode, **kwargs)
 
 
 def _convert_time_column(frame, time_col=None, time_index=None):
