@@ -73,6 +73,15 @@ class QueryEngine(metaclass=abc.ABCMeta):
             - ``retry_limit`` (int): max number of automatic retries
             - ``wait_interval`` (int): sleep interval until job finish
             - ``wait_callback`` (function): called every interval against job itself
+            - ``engine_version`` (str): run query with Hive 2 if this parameter
+              is set to ``"experimental"`` in ``HiveQueryEngine``.
+              https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
+
+            Meanwhile, when a following argument is set to ``True``, query is
+            deterministically issued via ``tdclient``.
+
+            - ``force_tdclient`` (bool): force Presto engines to issue a query
+              via ``tdclient`` rather than its default ``prestodb`` interface.
 
         Returns
         -------
@@ -119,7 +128,7 @@ class QueryEngine(metaclass=abc.ABCMeta):
         return header
 
     @abc.abstractmethod
-    def cursor(self, **kwargs):
+    def cursor(self, force_tdclient=False, **kwargs):
         pass
 
     @abc.abstractmethod
@@ -168,6 +177,9 @@ class QueryEngine(metaclass=abc.ABCMeta):
             - ``retry_limit`` (int): max number of automatic retries
             - ``wait_interval`` (int): sleep interval until job finish
             - ``wait_callback`` (function): called every interval against job itself
+            - ``engine_version`` (str): run query with Hive 2 if this parameter
+              is set to ``"experimental"`` in ``HiveQueryEngine``.
+              https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
 
         Returns
         -------
@@ -181,6 +193,7 @@ class QueryEngine(metaclass=abc.ABCMeta):
                 "retry_limit",
                 "wait_interval",
                 "wait_callback",
+                "engine_version",
             ]
         )
 
@@ -262,11 +275,16 @@ class PrestoQueryEngine(QueryEngine):
             "TD_PRESTO_API", urlparse(self.endpoint).netloc.replace("api", "api-presto")
         )
 
-    def cursor(self, **kwargs):
+    def cursor(self, force_tdclient=False, **kwargs):
         """Get cursor defined by DB-API.
 
         Parameters
         ----------
+        force_tdclient : bool
+            Specify whether the method always returns
+            :class:`tdclient.cursor.Cursor`.  If ``False``, returned cursor
+            type is dynamically selected depending on ``**kwargs``.
+
         **kwargs
             Treasure Data-specific optional query parameters. Giving these
             keyword arguments forces query engine to issue a query via Treasure
@@ -288,9 +306,9 @@ class PrestoQueryEngine(QueryEngine):
 
         Returns
         -------
-        prestodb.dbapi.Cursor, or tdclient.cursor.Cursor
+        :class:`prestodb.dbapi.Cursor`, or :class:`tdclient.cursor.Cursor`
         """
-        if len(kwargs) == 0:
+        if not force_tdclient and len(kwargs) == 0:
             return self.prestodb_connection.cursor()
 
         return self._get_tdclient_cursor(self.tdclient_connection, **kwargs)
@@ -350,11 +368,18 @@ class HiveQueryEngine(QueryEngine):
         """
         return "pytd/{0} (tdclient/{1})".format(__version__, tdclient.__version__)
 
-    def cursor(self, **kwargs):
+    def cursor(self, force_tdclient=True, **kwargs):
         """Get cursor defined by DB-API.
 
         Parameters
         ----------
+        force_tdclient : bool
+            Specify whether the method always returns
+            :class:`tdclient.cursor.Cursor`.  Currently, the parameter changes
+            nothing in ``HiveQueryEngine`` since
+            :class:`tdclient.cursor.Curosr` is the only option as a type of
+            returned value.
+
         **kwargs
             Treasure Data-specific optional query parameters. Giving these
             keyword arguments forces query engine to issue a query via Treasure
@@ -372,6 +397,9 @@ class HiveQueryEngine(QueryEngine):
             - ``retry_limit`` (int): max number of automatic retries
             - ``wait_interval`` (int): sleep interval until job finish
             - ``wait_callback`` (function): called every interval against job itself
+            - ``engine_version`` (str): run query with Hive 2 if this parameter
+              is set to ``"experimental"``.
+              https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083123/Using+Hive+2+to+Create+Queries
 
         Returns
         -------
