@@ -200,6 +200,11 @@ class InsertIntoWriter(Writer):
         if self.closed:
             raise RuntimeError("this writer is already closed and no longer available")
 
+        if isinstance(table, str):
+            raise TypeError(
+                "table '{}' should be pytd.table.Table, not str".format(table)
+            )
+
         _cast_dtypes(dataframe)
 
         column_names, column_types = _get_schema(dataframe)
@@ -230,7 +235,7 @@ class InsertIntoWriter(Writer):
         column_types : list of str
             Column types corresponding to the names. Note that Treasure Data
             supports limited amount of types as documented in:
-            https://support.treasuredata.com/hc/en-us/articles/360001266468-Schema-Management
+            https://tddocs.atlassian.net/wiki/spaces/PD/pages/1083743/Schema+Management
 
         if_exists : {'error', 'overwrite', 'append', 'ignore'}
             What happens when a target table already exists.
@@ -340,9 +345,12 @@ class BulkImportWriter(Writer):
                 Convert dataframe to temporary CSV file. Stable option but slower
                 than msgpack option because pytd saves dataframe as temporary CSV file,
                 then td-client converts it to msgpack.
+                Types of columns are guessed by ``pandas.read_csv`` and it causes
+                unintended type conversion e.g., 0-padded string ``"00012"`` into
+                integer ``12``.
             - msgpack
-                Convert to temporary msgpack.gz file. Fast option but might be
-                unstable because of skipping ``tdclient.API._prepare_file()``
+                Convert to temporary msgpack.gz file. Fast option but there is a
+                slight difference on type conversion compared to csv.
 
         keep_list : boolean, default: False
             If this argument is True, keep list or numpy.ndarray column as list, which
@@ -402,6 +410,11 @@ class BulkImportWriter(Writer):
         if self.closed:
             raise RuntimeError("this writer is already closed and no longer available")
 
+        if isinstance(table, str):
+            raise TypeError(
+                "table '{}' should be pytd.table.Table, not str".format(table)
+            )
+
         if "time" not in dataframe.columns:  # need time column for bulk import
             dataframe["time"] = int(time.time())
 
@@ -619,6 +632,11 @@ class SparkWriter(Writer):
         if if_exists not in ("error", "overwrite", "append", "ignore"):
             raise ValueError("invalid value for if_exists: {}".format(if_exists))
 
+        if isinstance(table, str):
+            raise TypeError(
+                "table '{}' should be pytd.table.Table, not str".format(table)
+            )
+
         if self.td_spark is None:
             self.td_spark = fetch_td_spark_context(
                 table.client.apikey,
